(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     36317,        991]
NotebookOptionsPosition[     33658,        902]
NotebookOutlinePosition[     34047,        919]
CellTagsIndexPosition[     34004,        916]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Creating Expressions for the Exit Set and Tangency Test Functions\
\>", "Title",
 CellChangeTimes->{{3.620645221615757*^9, 3.620645287821332*^9}, {
  3.6206453368335114`*^9, 3.6206453386646967`*^9}, {3.620728034083613*^9, 
  3.6207280366003513`*^9}},
 FontSize->24],

Cell[TextData[{
 "This ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " code requires the package ToMatlab, which can be found online."
}], "Text",
 CellChangeTimes->{{3.620645344726306*^9, 3.620645395306643*^9}}],

Cell[BoxData[
 RowBox[{"<<", "ToMatlab.m"}]], "Input",
 CellChangeTimes->{{3.590308020309566*^9, 3.590308091710916*^9}, {
  3.5903086238623734`*^9, 3.5903086277787933`*^9}}],

Cell["Right-hand side of the ordinary differential equation", "Text",
 CellChangeTimes->{{3.620645406534629*^9, 3.620645430488513*^9}, {
  3.620645873721039*^9, 3.620645884884808*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"lambda", " ", "=", " ", 
   RowBox[{
    RowBox[{"-", "1"}], "/", "10"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f1", " ", "=", " ", 
   RowBox[{
    RowBox[{"lambda", " ", "x"}], " ", "+", " ", "y", " ", "-", " ", 
    RowBox[{"x", "^", "3"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f2", " ", "=", " ", 
   RowBox[{
    RowBox[{"-", "x"}], " ", "+", " ", 
    RowBox[{"lambda", " ", "y"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f3", " ", "=", " ", 
   RowBox[{"5", " ", "z"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.590308102436681*^9, 3.5903081077447844`*^9}, {
   3.590308617994038*^9, 3.590308620159658*^9}, 3.590308719452248*^9, {
   3.600348188150208*^9, 3.600348188353923*^9}, {3.600348736302134*^9, 
   3.600348737195406*^9}, {3.600348833259295*^9, 3.600348864728463*^9}, {
   3.6003550184508677`*^9, 3.600355051765841*^9}, {3.600356515234137*^9, 
   3.600356612407469*^9}, 3.6004189065213842`*^9, {3.600418939611384*^9, 
   3.6004189399653587`*^9}, 3.600419138263379*^9, {3.6005259725665503`*^9, 
   3.600525998671414*^9}, {3.609330463983664*^9, 3.609330482371224*^9}, {
   3.609337280391674*^9, 3.6093372813949003`*^9}, {3.6095847010523853`*^9, 
   3.609584710673324*^9}}],

Cell["\<\
Center point of the set, basis transformation and scaling matrix\
\>", "Text",
 CellChangeTimes->{{3.620645457666828*^9, 3.620645546101337*^9}, {
  3.620645891032233*^9, 3.620645912173396*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"p", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VV", " ", "=", " ", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DD", " ", "=", " ", 
   RowBox[{"DiagonalMatrix", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"3", "/", "10"}], ",", 
      RowBox[{"3", "/", "10"}], ",", 
      RowBox[{"3", "/", "10"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"VV", " ", "//", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{"DD", " ", "//", "MatrixForm"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.609330541505465*^9, 3.60933056423706*^9}, {
   3.609330648400013*^9, 3.609330652536214*^9}, {3.609330697046074*^9, 
   3.6093309041129827`*^9}, {3.609584722230275*^9, 3.6095847680407467`*^9}, 
   3.6095850322701683`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.6095850486007557`*^9, 3.609779878811466*^9, 
  3.620728591292197*^9, 3.620728741395215*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0"},
     {"0", "1", "0"},
     {"0", "0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6095850486007557`*^9, 3.609779878811466*^9, 
  3.620728591292197*^9, 3.620728741399653*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["3", "10"], "0", "0"},
     {"0", 
      FractionBox["3", "10"], "0"},
     {"0", "0", 
      FractionBox["3", "10"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6095850486007557`*^9, 3.609779878811466*^9, 
  3.620728591292197*^9, 3.620728741403412*^9}]
}, Open  ]],

Cell["Representation of the transformed coordinates", "Text",
 CellChangeTimes->{{3.6206455621783333`*^9, 3.6206456112197313`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sp", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Inverse", "[", "DD", "]"}], " ", ".", " ", 
    RowBox[{"Inverse", "[", "VV", "]"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "z"}], "}"}], " ", "-", " ", "p"}], 
     ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.609331002701733*^9, 3.6093310719584017`*^9}, {
  3.609331215365861*^9, 3.609331215968697*^9}, {3.609331261811542*^9, 
  3.609331326577335*^9}, {3.6093313822919893`*^9, 3.6093313930136833`*^9}, {
  3.6093320273257093`*^9, 3.609332031514982*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"10", " ", "x"}], "3"], ",", 
   FractionBox[
    RowBox[{"10", " ", "y"}], "3"], ",", 
   FractionBox[
    RowBox[{"10", " ", "z"}], "3"]}], "}"}]], "Output",
 CellChangeTimes->{{3.609331009782016*^9, 3.6093310726643877`*^9}, 
   3.6093312163422737`*^9, {3.609331304648489*^9, 3.6093313270037518`*^9}, 
   3.6093313943181334`*^9, 3.609331869122426*^9, 3.609332170221916*^9, 
   3.609332985776071*^9, 3.609337069150855*^9, 3.6093372856333942`*^9, 
   3.609337784162763*^9, 3.6093379999991283`*^9, 3.609585000832637*^9, 
   3.60958504871727*^9, 3.609779878897612*^9, 3.620728600483568*^9, 
   3.6207287414338617`*^9}]
}, Open  ]],

Cell["Level set representation of the manifold M", "Text",
 CellChangeTimes->{{3.620645591185729*^9, 3.6206456232405243`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Phi0", " ", "=", " ", 
  RowBox[{
   RowBox[{"sp1", "*", "sp1"}], " ", "+", " ", 
   RowBox[{"sp2", "*", "sp2"}], "+", 
   RowBox[{"sp3", "*", "sp3"}], "-", "1"}]}], "\[IndentingNewLine]", 
 RowBox[{"Phi", " ", "=", " ", 
  RowBox[{"Expand", "[", 
   RowBox[{"Phi0", " ", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sp1", "\[Rule]", 
       RowBox[{"sp", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", 
      RowBox[{"sp2", "\[Rule]", 
       RowBox[{"sp", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ",", 
      RowBox[{"sp3", "\[Rule]", 
       RowBox[{"sp", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}]}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.609331397422073*^9, 3.6093315491116533`*^9}, {
  3.609332038132525*^9, 3.609332072139048*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "+", 
  SuperscriptBox["sp1", "2"], "+", 
  SuperscriptBox["sp2", "2"], "+", 
  SuperscriptBox["sp3", "2"]}]], "Output",
 CellChangeTimes->{
  3.609331400869627*^9, {3.609331489947171*^9, 3.609331550699538*^9}, 
   3.6093318710125847`*^9, 3.609332172411734*^9, 3.6093329858081303`*^9, 
   3.609337070819397*^9, 3.6093372870416183`*^9, 3.609337784195529*^9, 
   3.609338000031266*^9, 3.609585000878079*^9, 3.60958504875518*^9, 
   3.6097798789315767`*^9, 3.620728604159783*^9, 3.620728741466201*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "+", 
  FractionBox[
   RowBox[{"100", " ", 
    SuperscriptBox["x", "2"]}], "9"], "+", 
  FractionBox[
   RowBox[{"100", " ", 
    SuperscriptBox["y", "2"]}], "9"], "+", 
  FractionBox[
   RowBox[{"100", " ", 
    SuperscriptBox["z", "2"]}], "9"]}]], "Output",
 CellChangeTimes->{
  3.609331400869627*^9, {3.609331489947171*^9, 3.609331550699538*^9}, 
   3.6093318710125847`*^9, 3.609332172411734*^9, 3.6093329858081303`*^9, 
   3.609337070819397*^9, 3.6093372870416183`*^9, 3.609337784195529*^9, 
   3.609338000031266*^9, 3.609585000878079*^9, 3.60958504875518*^9, 
   3.6097798789315767`*^9, 3.620728604159783*^9, 3.6207287414704723`*^9}]
}, Open  ]],

Cell["Normal vector field", "Text",
 CellChangeTimes->{{3.620645935139843*^9, 3.620645948489401*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"n1", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"D", "[", 
    RowBox[{"Phi", ",", "x"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"n2", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"D", "[", 
    RowBox[{"Phi", ",", "y"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"n3", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"D", "[", 
    RowBox[{"Phi", ",", "z"}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.600348916357007*^9, 3.600348944703347*^9}, {
   3.6003490656964903`*^9, 3.6003490728832493`*^9}, {3.600355056855118*^9, 
   3.600355073967155*^9}, {3.6003566213354807`*^9, 3.6003566326141443`*^9}, 
   3.600419135269508*^9, {3.600420062055184*^9, 3.600420068094103*^9}, 
   3.6004201685500937`*^9, {3.600420638533017*^9, 3.600420761137501*^9}, {
   3.6005260531232986`*^9, 3.600526081371461*^9}, {3.600526548816533*^9, 
   3.600526662110641*^9}, {3.609331568549148*^9, 3.609331641810082*^9}, {
   3.609332086490802*^9, 3.6093320914671497`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"200", " ", "x"}], "9"]], "Output",
 CellChangeTimes->{{3.6093316147723083`*^9, 3.609331642912225*^9}, 
   3.6093318731830606`*^9, 3.609332174216323*^9, 3.609332985860364*^9, 
   3.6093370744129763`*^9, 3.609337290801646*^9, 3.6093377842463417`*^9, 
   3.609338000082749*^9, 3.609585000929132*^9, 3.60958504878929*^9, 
   3.6097798789844503`*^9, 3.620728608357971*^9, 3.620728741500997*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"200", " ", "y"}], "9"]], "Output",
 CellChangeTimes->{{3.6093316147723083`*^9, 3.609331642912225*^9}, 
   3.6093318731830606`*^9, 3.609332174216323*^9, 3.609332985860364*^9, 
   3.6093370744129763`*^9, 3.609337290801646*^9, 3.6093377842463417`*^9, 
   3.609338000082749*^9, 3.609585000929132*^9, 3.60958504878929*^9, 
   3.6097798789844503`*^9, 3.620728608357971*^9, 3.620728741505018*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"200", " ", "z"}], "9"]], "Output",
 CellChangeTimes->{{3.6093316147723083`*^9, 3.609331642912225*^9}, 
   3.6093318731830606`*^9, 3.609332174216323*^9, 3.609332985860364*^9, 
   3.6093370744129763`*^9, 3.609337290801646*^9, 3.6093377842463417`*^9, 
   3.609338000082749*^9, 3.609585000929132*^9, 3.60958504878929*^9, 
   3.6097798789844503`*^9, 3.620728608357971*^9, 3.620728741507819*^9}]
}, Open  ]],

Cell["Entries of the Hessian of \[CapitalPhi]", "Text",
 CellChangeTimes->{{3.62064597445404*^9, 3.6206459932365513`*^9}, {
  3.62064605230657*^9, 3.620646055834035*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"H11", "=", 
   RowBox[{"D", "[", 
    RowBox[{"n1", ",", "x"}], "]"}]}], ";", 
  RowBox[{"H12", "=", 
   RowBox[{"D", "[", 
    RowBox[{"n1", ",", "y"}], "]"}]}], ";", 
  RowBox[{"H13", "=", 
   RowBox[{"D", "[", 
    RowBox[{"n1", ",", "z"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"H21", "=", 
   RowBox[{"D", "[", 
    RowBox[{"n2", ",", "x"}], "]"}]}], ";", 
  RowBox[{"H22", "=", 
   RowBox[{"D", "[", 
    RowBox[{"n2", ",", "y"}], "]"}]}], ";", 
  RowBox[{"H23", "=", 
   RowBox[{"D", "[", 
    RowBox[{"n2", ",", "z"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"H31", "=", 
    RowBox[{"D", "[", 
     RowBox[{"n3", ",", "x"}], "]"}]}], ";", 
   RowBox[{"H32", "=", 
    RowBox[{"D", "[", 
     RowBox[{"n3", ",", "y"}], "]"}]}], ";", 
   RowBox[{"H33", "=", 
    RowBox[{"D", "[", 
     RowBox[{"n3", ",", "z"}], "]"}]}], ";"}], 
  " "}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.6093316581136913`*^9, 3.60933176430402*^9}, {
  3.609332095941586*^9, 3.6093321183099823`*^9}, {3.609337090690591*^9, 
  3.6093372084179373`*^9}, {3.6093372503781853`*^9, 3.609337448070187*^9}, {
  3.620646075998433*^9, 3.620646077428384*^9}}],

Cell["Exit set test function u", "Text",
 CellChangeTimes->{{3.6206460882000103`*^9, 3.620646103637946*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ut", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"n1", "*", "f1"}], "+", 
    RowBox[{"n2", "*", "f2"}], "+", 
    RowBox[{"n3", "*", "f3"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.609331801952739*^9, 3.609331833504445*^9}, {
  3.609332124155941*^9, 3.609332145445249*^9}, {3.609332185927738*^9, 
  3.609332188720695*^9}, {3.609332613268766*^9, 3.60933261646976*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["20", "9"]}], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["x", "2"], "+", 
    RowBox[{"10", " ", 
     SuperscriptBox["x", "4"]}], "+", 
    SuperscriptBox["y", "2"], "-", 
    RowBox[{"50", " ", 
     SuperscriptBox["z", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.609331821443535*^9, 3.6093318339450817`*^9}, 
   3.609331880794528*^9, {3.6093321797158623`*^9, 3.6093321898295813`*^9}, 
   3.609332617175012*^9, 3.60933298596*^9, 3.609337472542982*^9, 
   3.609337784341804*^9, 3.6093380001648703`*^9, 3.609585001009232*^9, 
   3.6095850488506823`*^9, 3.6097798790445747`*^9, 3.620728618485064*^9, 
   3.620728741562153*^9}]
}, Open  ]],

Cell["Modified tangency test function w", "Text",
 CellChangeTimes->{{3.620728193993701*^9, 3.62072821921743*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"f11", " ", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{"f1", ",", "x"}], "]"}]}], ";", " ", 
  RowBox[{"f12", " ", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{"f1", ",", "y"}], "]"}]}], ";", 
  RowBox[{"f13", " ", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{"f1", ",", "z"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f21", " ", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{"f2", ",", "x"}], "]"}]}], ";", " ", 
  RowBox[{"f22", " ", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{"f2", ",", "y"}], "]"}]}], ";", 
  RowBox[{"f23", " ", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{"f2", ",", "z"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f31", " ", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{"f3", ",", "x"}], "]"}]}], ";", " ", 
  RowBox[{"f32", " ", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{"f3", ",", "y"}], "]"}]}], ";", 
  RowBox[{"f33", " ", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{"f3", ",", "z"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"wt1", " ", "=", " ", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"f11", "*", "f1"}], "+", 
        RowBox[{"f12", "*", "f2"}], "+", 
        RowBox[{"f13", "*", "f3"}]}], ")"}], "*", "n1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"f21", "*", "f1"}], "+", 
        RowBox[{"f22", "*", "f2"}], "+", 
        RowBox[{"f23", "*", "f3"}]}], ")"}], "*", "n2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"f31", "*", "f1"}], "+", 
        RowBox[{"f32", "*", "f2"}], "+", 
        RowBox[{"f33", "*", "f3"}]}], ")"}], "*", "n3"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"wt2", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"H11", "*", "f1"}], "+", 
        RowBox[{"H12", "*", "f2"}], "+", 
        RowBox[{"H13", "*", "f3"}]}], ")"}], "*", "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"H21", "*", "f1"}], "+", 
        RowBox[{"H22", "*", "f2"}], "+", 
        RowBox[{"H23", "*", "f3"}]}], ")"}], "*", "f2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"H31", "*", "f1"}], "+", 
        RowBox[{"H32", "*", "f2"}], "+", 
        RowBox[{"H33", "*", "f3"}]}], ")"}], "*", "f3"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"wt", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"wt1", "+", "wt2"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.609332235529069*^9, 3.609332246026722*^9}, {
  3.609332291119013*^9, 3.609332385541844*^9}, {3.609332528825124*^9, 
  3.609332606930108*^9}, {3.620728224406918*^9, 3.6207282311688013`*^9}, {
  3.620728629214862*^9, 3.620728631542589*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["4", "9"], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["x", "2"], "+", 
    RowBox[{"30", " ", 
     SuperscriptBox["x", "4"]}], "+", 
    RowBox[{"200", " ", 
     SuperscriptBox["x", "6"]}], "-", 
    RowBox[{"200", " ", 
     SuperscriptBox["x", "3"], " ", "y"}], "+", 
    SuperscriptBox["y", "2"], "+", 
    RowBox[{"2500", " ", 
     SuperscriptBox["z", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.6093377844508467`*^9, 3.609338000349504*^9, 3.60958500111202*^9, 
   3.6095850489236507`*^9, 3.609779879112372*^9, {3.6207286237424803`*^9, 
   3.620728632481698*^9}, 3.620728741601445*^9}]
}, Open  ]],

Cell["Parameterization via spherical coordinates", "Text",
 CellChangeTimes->{{3.6207282683569593`*^9, 3.620728327421052*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"xx", " ", "=", " ", 
  RowBox[{"p", " ", "+", " ", 
   RowBox[{"VV", " ", ".", " ", "DD", " ", ".", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Sin", "[", "theta", "]"}], " ", 
       RowBox[{"Cos", "[", "phi", "]"}]}], ",", 
      RowBox[{
       RowBox[{"Sin", "[", "theta", "]"}], " ", 
       RowBox[{"Sin", "[", "phi", "]"}]}], ",", 
      RowBox[{"Cos", "[", "theta", "]"}]}], 
     "}"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r1", "=", 
   RowBox[{"xx", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r2", "=", 
   RowBox[{"xx", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r3", "=", 
   RowBox[{"xx", "[", 
    RowBox[{"[", "3", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]"}], "Input",\

 CellChangeTimes->{{3.600348886643111*^9, 3.600348912928404*^9}, {
   3.600348952578211*^9, 3.600349021546104*^9}, {3.600349078174562*^9, 
   3.600349083376483*^9}, {3.600356655857662*^9, 3.600356813717071*^9}, {
   3.600418927087166*^9, 3.600418936447507*^9}, 3.600419132176093*^9, {
   3.6004207769194117`*^9, 3.600420865099214*^9}, {3.609332649157967*^9, 
   3.609332730796319*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["3", "10"], " ", 
    RowBox[{"Cos", "[", "phi", "]"}], " ", 
    RowBox[{"Sin", "[", "theta", "]"}]}], ",", 
   RowBox[{
    FractionBox["3", "10"], " ", 
    RowBox[{"Sin", "[", "phi", "]"}], " ", 
    RowBox[{"Sin", "[", "theta", "]"}]}], ",", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{"Cos", "[", "theta", "]"}]}], "10"]}], "}"}]], "Output",
 CellChangeTimes->{3.609332731448638*^9, 3.6093329860599194`*^9, 
  3.6093377847862253`*^9, 3.609338000655768*^9, 3.609585001194191*^9, 
  3.609585049006283*^9, 3.6097798792000637`*^9, 3.620728638129767*^9, 
  3.620728741633686*^9}]
}, Open  ]],

Cell["Parameterized exit set test function", "Text",
 CellChangeTimes->{{3.620728341181584*^9, 3.6207283543082047`*^9}, 
   3.620728649269931*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"uu", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"ut", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "\[Rule]", "r1"}], ",", 
      RowBox[{"y", "\[Rule]", "r2"}], ",", 
      RowBox[{"z", "\[Rule]", "r3"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"uutheta", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"D", "[", 
    RowBox[{"uu", ",", "theta"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"uuphi", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"D", "[", 
    RowBox[{"uu", ",", "phi"}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.600418899430791*^9, 3.600418930379703*^9}, {
  3.600419118235984*^9, 3.6004191226485577`*^9}, {3.609332749549315*^9, 
  3.6093327518859653`*^9}, {3.609332809405333*^9, 3.6093328359769583`*^9}, {
  3.609332871703424*^9, 3.609332872607432*^9}, {3.620728404629339*^9, 
  3.62072841058897*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"10", " ", 
   SuperscriptBox[
    RowBox[{"Cos", "[", "theta", "]"}], "2"]}], "-", 
  RowBox[{
   FractionBox["1", "50"], " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", "theta", "]"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"10", " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "phi", "]"}], "2"]}], "+", 
     RowBox[{"10", " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "phi", "]"}], "2"]}], "+", 
     RowBox[{"9", " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "phi", "]"}], "4"], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "theta", "]"}], "2"]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.6093328276760283`*^9, 3.609332837244549*^9}, 
   3.609332874524419*^9, 3.609332986907508*^9, 3.609337785647924*^9, 
   3.609338001514351*^9, 3.609585001350918*^9, 3.60958504909262*^9, 
   3.609779879292679*^9, 3.620728652146522*^9, 3.620728741727639*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["2", "25"]}], " ", 
  RowBox[{"Cos", "[", "theta", "]"}], " ", 
  RowBox[{"Sin", "[", "theta", "]"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"5", " ", 
     SuperscriptBox[
      RowBox[{"Cos", "[", "phi", "]"}], "2"]}], "+", 
    RowBox[{"5", " ", 
     RowBox[{"(", 
      RowBox[{"50", "+", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "phi", "]"}], "2"]}], ")"}]}], "+", 
    RowBox[{"9", " ", 
     SuperscriptBox[
      RowBox[{"Cos", "[", "phi", "]"}], "4"], " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "theta", "]"}], "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.6093328276760283`*^9, 3.609332837244549*^9}, 
   3.609332874524419*^9, 3.609332986907508*^9, 3.609337785647924*^9, 
   3.609338001514351*^9, 3.609585001350918*^9, 3.60958504909262*^9, 
   3.609779879292679*^9, 3.620728652146522*^9, 3.6207287417757893`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["18", "25"], " ", 
  SuperscriptBox[
   RowBox[{"Cos", "[", "phi", "]"}], "3"], " ", 
  RowBox[{"Sin", "[", "phi", "]"}], " ", 
  SuperscriptBox[
   RowBox[{"Sin", "[", "theta", "]"}], "4"]}]], "Output",
 CellChangeTimes->{{3.6093328276760283`*^9, 3.609332837244549*^9}, 
   3.609332874524419*^9, 3.609332986907508*^9, 3.609337785647924*^9, 
   3.609338001514351*^9, 3.609585001350918*^9, 3.60958504909262*^9, 
   3.609779879292679*^9, 3.620728652146522*^9, 3.6207287417785378`*^9}]
}, Open  ]],

Cell["Parameterized modified tangency test function", "Text",
 CellChangeTimes->{{3.620728375023975*^9, 3.620728395646682*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"ww", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"wt", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "\[Rule]", "r1"}], ",", 
      RowBox[{"y", "\[Rule]", "r2"}], ",", 
      RowBox[{"z", "\[Rule]", "r3"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"wwtheta", " ", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{"ww", ",", "theta"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"wwphi", " ", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{"ww", ",", "phi"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.6003490388444643`*^9, 3.600349051111763*^9}, {
   3.600356651909671*^9, 3.6003566528794727`*^9}, {3.600418965359694*^9, 
   3.6004191259277983`*^9}, {3.6004200743535433`*^9, 3.60042016376306*^9}, 
   3.609332757957633*^9, {3.6093328481265574`*^9, 3.6093328552195377`*^9}, {
   3.609332898981811*^9, 3.609332912251501*^9}, {3.620728368943573*^9, 
   3.620728372743197*^9}, {3.620728661532589*^9, 3.620728668606367*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "1250"], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"125000", " ", 
     SuperscriptBox[
      RowBox[{"Cos", "[", "theta", "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"Sin", "[", "theta", "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"50", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "phi", "]"}], "2"]}], "+", 
       RowBox[{"50", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "phi", "]"}], "2"]}], "+", 
       RowBox[{"135", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "phi", "]"}], "4"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "theta", "]"}], "2"]}], "-", 
       RowBox[{"900", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "phi", "]"}], "3"], " ", 
        RowBox[{"Sin", "[", "phi", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "theta", "]"}], "2"]}], "+", 
       RowBox[{"81", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "phi", "]"}], "6"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "theta", "]"}], "4"]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.609332859701844*^9, 3.609332923016336*^9, 3.609332993546068*^9, 
   3.609337792406827*^9, 3.609338008032419*^9, 3.6095850016108418`*^9, 
   3.609585049389716*^9, 3.609779879581571*^9, {3.6207286578309793`*^9, 
   3.620728670746015*^9}, 3.6207287420001793`*^9}]
}, Open  ]],

Cell["\<\
Generate Matlab files with the expressions for u, w, and their derivatives\
\>", "Text",
 CellChangeTimes->{{3.620728425804316*^9, 3.620728453566268*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"file0", " ", "=", " ", 
   RowBox[{"OpenWrite", "[", "\"\<./eval_c1u.m\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"WriteMatlab", "[", 
   RowBox[{
   "uu", ",", "file0", ",", 
    "\"\<function z=eval_c1u(x,y)\\nphi=x;\\ntheta=y;\\nz\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Close", "[", "file0", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"file1", " ", "=", " ", 
   RowBox[{"OpenWrite", "[", "\"\<./eval_c1ux.m\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"WriteMatlab", "[", 
   RowBox[{
   "uuphi", ",", "file1", ",", 
    "\"\<function z=eval_c1ux(x,y)\\nphi=x;\\ntheta=y;\\nz\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Close", "[", "file1", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"file2", " ", "=", " ", 
   RowBox[{"OpenWrite", "[", "\"\<./eval_c1uy.m\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"WriteMatlab", "[", 
   RowBox[{
   "uutheta", ",", "file2", ",", 
    "\"\<function z=eval_c1uy(x,y)\\nphi=x;\\ntheta=y;\\nz\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Close", "[", "file2", "]"}]}], "Input",
 CellChangeTimes->{{3.590308287676893*^9, 3.590308320859693*^9}, {
   3.5903086699617777`*^9, 3.590308684752911*^9}, {3.600349357344021*^9, 
   3.600349403618578*^9}, {3.600349969620274*^9, 3.600350028230749*^9}, {
   3.600355099956736*^9, 3.600355102115855*^9}, {3.600356466331204*^9, 
   3.600356494154355*^9}, 3.6004193384539557`*^9, {3.600419401681361*^9, 
   3.6004194343063297`*^9}, {3.609779473715246*^9, 3.6097795065178547`*^9}, {
   3.620728687767254*^9, 3.6207286969694157`*^9}}],

Cell[BoxData["\<\"./eval_c1u.m\"\>"], "Output",
 CellChangeTimes->{
  3.590308328316983*^9, 3.590308728531027*^9, {3.600349378286858*^9, 
   3.600349404557062*^9}, 3.600350029252308*^9, 3.600355103413529*^9, 
   3.600357794771079*^9, 3.600419500349259*^9, 3.600420184352478*^9, 
   3.600421030544009*^9, 3.60042253538667*^9, 3.600526906067198*^9, 
   3.609332993627798*^9, 3.60933788344203*^9, 3.6093380992781754`*^9, 
   3.609585001730627*^9, 3.6095850504035883`*^9, 3.6097798805982037`*^9, 
   3.6207286750966578`*^9, 3.6207287420366173`*^9}],

Cell[BoxData["\<\"./eval_c1ux.m\"\>"], "Output",
 CellChangeTimes->{
  3.590308328316983*^9, 3.590308728531027*^9, {3.600349378286858*^9, 
   3.600349404557062*^9}, 3.600350029252308*^9, 3.600355103413529*^9, 
   3.600357794771079*^9, 3.600419500349259*^9, 3.600420184352478*^9, 
   3.600421030544009*^9, 3.60042253538667*^9, 3.600526906067198*^9, 
   3.609332993627798*^9, 3.60933788344203*^9, 3.6093380992781754`*^9, 
   3.609585001730627*^9, 3.6095850504035883`*^9, 3.6097798805982037`*^9, 
   3.6207286750966578`*^9, 3.620728742041*^9}],

Cell[BoxData["\<\"./eval_c1uy.m\"\>"], "Output",
 CellChangeTimes->{
  3.590308328316983*^9, 3.590308728531027*^9, {3.600349378286858*^9, 
   3.600349404557062*^9}, 3.600350029252308*^9, 3.600355103413529*^9, 
   3.600357794771079*^9, 3.600419500349259*^9, 3.600420184352478*^9, 
   3.600421030544009*^9, 3.60042253538667*^9, 3.600526906067198*^9, 
   3.609332993627798*^9, 3.60933788344203*^9, 3.6093380992781754`*^9, 
   3.609585001730627*^9, 3.6095850504035883`*^9, 3.6097798805982037`*^9, 
   3.6207286750966578`*^9, 3.620728742043939*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"file0", " ", "=", " ", 
   RowBox[{"OpenWrite", "[", "\"\<./eval_c1w.m\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"WriteMatlab", "[", 
   RowBox[{
   "ww", ",", "file0", ",", 
    "\"\<function z=eval_c1w(x,y)\\nphi=x;\\ntheta=y;\\nz\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Close", "[", "file0", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"file1", " ", "=", " ", 
   RowBox[{"OpenWrite", "[", "\"\<./eval_c1wx.m\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"WriteMatlab", "[", 
   RowBox[{
   "wwphi", ",", "file1", ",", 
    "\"\<function z=eval_c1wx(x,y)\\nphi=x;\\ntheta=y;\\nz\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Close", "[", "file1", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"file2", " ", "=", " ", 
   RowBox[{"OpenWrite", "[", "\"\<./eval_c1wy.m\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"WriteMatlab", "[", 
   RowBox[{
   "wwtheta", ",", "file2", ",", 
    "\"\<function z=eval_c1wy(x,y)\\nphi=x;\\ntheta=y;\\nz\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Close", "[", "file2", "]"}]}], "Input",
 CellChangeTimes->{{3.590308410333744*^9, 3.590308506682131*^9}, {
  3.600349385097417*^9, 3.600349413724996*^9}, {3.600350056204969*^9, 
  3.6003500854121943`*^9}, {3.600355112138747*^9, 3.6003551138086023`*^9}, {
  3.600356475006428*^9, 3.600356497007473*^9}, {3.600419334595633*^9, 
  3.600419371820793*^9}, {3.60933295551642*^9, 3.609332963043126*^9}, {
  3.609779515085656*^9, 3.609779540448455*^9}, {3.620728470749956*^9, 
  3.620728474655363*^9}, {3.620728701135644*^9, 3.620728708247547*^9}}],

Cell[BoxData["\<\"./eval_c1w.m\"\>"], "Output",
 CellChangeTimes->{3.590308509655202*^9, 3.590308732783059*^9, 
  3.60034941526378*^9, 3.600350097757213*^9, 3.600355121162931*^9, 
  3.600357798414645*^9, 3.600419504221857*^9, 3.6004201843967857`*^9, 
  3.600421030580587*^9, 3.6004225354277697`*^9, 3.600526906221903*^9, 
  3.6093329936613503`*^9, 3.609337883483107*^9, 3.6093380993160954`*^9, 
  3.6095850017806797`*^9, 3.6095850504423437`*^9, 3.6097798806372957`*^9, 
  3.6207286788343563`*^9, 3.6207287420867777`*^9}],

Cell[BoxData["\<\"./eval_c1wx.m\"\>"], "Output",
 CellChangeTimes->{3.590308509655202*^9, 3.590308732783059*^9, 
  3.60034941526378*^9, 3.600350097757213*^9, 3.600355121162931*^9, 
  3.600357798414645*^9, 3.600419504221857*^9, 3.6004201843967857`*^9, 
  3.600421030580587*^9, 3.6004225354277697`*^9, 3.600526906221903*^9, 
  3.6093329936613503`*^9, 3.609337883483107*^9, 3.6093380993160954`*^9, 
  3.6095850017806797`*^9, 3.6095850504423437`*^9, 3.6097798806372957`*^9, 
  3.6207286788343563`*^9, 3.620728742091029*^9}],

Cell[BoxData["\<\"./eval_c1wy.m\"\>"], "Output",
 CellChangeTimes->{3.590308509655202*^9, 3.590308732783059*^9, 
  3.60034941526378*^9, 3.600350097757213*^9, 3.600355121162931*^9, 
  3.600357798414645*^9, 3.600419504221857*^9, 3.6004201843967857`*^9, 
  3.600421030580587*^9, 3.6004225354277697`*^9, 3.600526906221903*^9, 
  3.6093329936613503`*^9, 3.609337883483107*^9, 3.6093380993160954`*^9, 
  3.6095850017806797`*^9, 3.6095850504423437`*^9, 3.6097798806372957`*^9, 
  3.6207286788343563`*^9, 3.620728742094001*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.590308521211349*^9, 3.5903085988898363`*^9}, {
   3.600349422524358*^9, 3.60034943502474*^9}, {3.600350103587154*^9, 
   3.6003501266064796`*^9}, {3.600355130572266*^9, 3.600355132294589*^9}, {
   3.600356479159264*^9, 3.6003564999359617`*^9}, 3.600419387848126*^9}]
}, Open  ]]
},
WindowSize->{1313, 747},
WindowMargins->{{Automatic, 50}, {Automatic, 23}},
Magnification:>1.5 Inherited,
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (September 9, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 275, 6, 103, "Title"],
Cell[857, 30, 219, 6, 46, "Text"],
Cell[1079, 38, 173, 3, 43, "Input"],
Cell[1255, 43, 184, 2, 46, "Text"],
Cell[1442, 47, 1271, 27, 119, "Input"],
Cell[2716, 76, 203, 4, 46, "Text"],
Cell[CellGroupData[{
Cell[2944, 84, 1160, 30, 169, "Input"],
Cell[4107, 116, 196, 4, 43, "Output"],
Cell[4306, 122, 730, 20, 108, "Output"],
Cell[5039, 144, 808, 23, 142, "Output"]
}, Open  ]],
Cell[5862, 170, 131, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[6018, 175, 612, 14, 43, "Input"],
Cell[6633, 191, 684, 15, 66, "Output"]
}, Open  ]],
Cell[7332, 209, 126, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[7483, 214, 806, 21, 69, "Input"],
Cell[8292, 237, 544, 11, 45, "Output"],
Cell[8839, 250, 687, 17, 70, "Output"]
}, Open  ]],
Cell[9541, 270, 101, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[9667, 275, 1023, 20, 94, "Input"],
Cell[10693, 297, 428, 7, 66, "Output"],
Cell[11124, 306, 428, 7, 66, "Output"],
Cell[11555, 315, 428, 7, 66, "Output"]
}, Open  ]],
Cell[11998, 325, 170, 2, 46, "Text"],
Cell[12171, 329, 1235, 36, 119, "Input"],
Cell[13409, 367, 108, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[13542, 372, 419, 9, 43, "Input"],
Cell[13964, 383, 698, 17, 66, "Output"]
}, Open  ]],
Cell[14677, 403, 114, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[14816, 408, 2828, 83, 219, "Input"],
Cell[17647, 493, 650, 18, 66, "Output"]
}, Open  ]],
Cell[18312, 514, 126, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[18463, 519, 1245, 32, 144, "Input"],
Cell[19711, 553, 657, 17, 66, "Output"]
}, Open  ]],
Cell[20383, 573, 146, 2, 46, "Text"],
Cell[CellGroupData[{
Cell[20554, 579, 919, 22, 94, "Input"],
Cell[21476, 603, 940, 25, 66, "Output"],
Cell[22419, 630, 912, 24, 66, "Output"],
Cell[23334, 656, 520, 11, 66, "Output"]
}, Open  ]],
Cell[23869, 670, 127, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[24021, 675, 1013, 23, 94, "Input"],
Cell[25037, 700, 1456, 40, 98, "Output"]
}, Open  ]],
Cell[26508, 743, 164, 3, 46, "Text"],
Cell[CellGroupData[{
Cell[26697, 750, 1682, 40, 244, "Input"],
Cell[28382, 792, 544, 8, 43, "Output"],
Cell[28929, 802, 540, 8, 43, "Output"],
Cell[29472, 812, 543, 8, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30052, 825, 1693, 40, 244, "Input"],
Cell[31748, 867, 520, 7, 43, "Output"],
Cell[32271, 876, 519, 7, 43, "Output"],
Cell[32793, 885, 519, 7, 43, "Output"]
}, Open  ]],
Cell[33327, 895, 315, 4, 77, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
